==> haskell-hls-graph-2.1.0.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.1.0.0
visibility:           public
id:                   hls-graph-2.1.0.0-FIdXKrsIxI2GLjave8LyYM
key:                  hls-graph-2.1.0.0-FIdXKrsIxI2GLjave8LyYM
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  5d06f1eb69ea99a21987f81074e9253f
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.1.0.0-FIdXKrsIxI2GLjave8LyYM
depends:
    aeson-2.1.2.1-HPwo2VO3hzcFr4fiGB5Oro
    async-2.2.5-J9V4nOmLz7f63UCPGEHw4R base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-6O0vpR35xmz4TsZbH7SN4x filepath-1.4.2.2
    focus-1.0.3.2-JPyqIAvCkVv5mMp3C0ySCb
    hashable-1.4.4.0-HCL6HYi7vZb6weAXUagHtJ
    js-dgtable-0.5.2-GJOZPjRBXVeCze8bD7YdfT
    js-flot-0.8.3-IKtJvuN3TOl6yoqyRfRs9e
    js-jquery-3.7.1-LHetIrDaPtC3v5E1fnJdJe
    list-t-1.0.5.6-ELafnR4S5yFJzNRfwrxIh stm-2.5.1.0
    stm-containers-1.2.1.1-3j0hGTItZOSIWTrrSagjXZ text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-DYznH1vHiFW9UOG5RP6OX5
    unordered-containers-0.2.20-FFF0GulGLFtAHq6N1Lkm0s

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-graph-2.1.0.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.1.0.0
visibility:           public
id:                   hls-graph-2.1.0.0-5eNOijEjeSCIPZo7cMnfGt
key:                  hls-graph-2.1.0.0-5eNOijEjeSCIPZo7cMnfGt
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  434bac33454c6a961b4fdc44f00bab1c
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.1.0.0-5eNOijEjeSCIPZo7cMnfGt
depends:
    aeson-2.1.2.1-8gRdOgbBkF57DAEniCzHis
    async-2.2.5-JsOMVyOozRP6jACwcJZjUc base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-HFVkAG9ZjF7KRVgcoT9Nb3 filepath-1.4.2.2
    focus-1.0.3.2-L1Srd8UCLCtrZIhn2AtCD
    hashable-1.4.4.0-C1fFIG7AZLC7j0jzLm97Uw
    js-dgtable-0.5.2-GJOZPjRBXVeCze8bD7YdfT
    js-flot-0.8.3-IKtJvuN3TOl6yoqyRfRs9e
    js-jquery-3.7.1-46PD64pNzuHIIQmnfrauPt
    list-t-1.0.5.6-Fpo3lj5zjMQ2zGLPr7hSsJ stm-2.5.1.0
    stm-containers-1.2.1.1-15UMirsv2MAP8nCL6dyxx text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-0.2.25.1-HBosFkLH3dKBKd3HpxN2GY
    unordered-containers-0.2.20-obNV32ZSreHxgWRz6JrKP

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
